module.exports = defineTest({
	description: 'adjust line-break handling when dealing with pure annotations'
});
